@@ -49,6 +49,8 @@ def create_parser(allow_mandatory=True):
                         default="none", help="Chunking type to use")
     parser.add_argument("--timeout-multiplier", action="store", type=float, default=1,
                         help="Multiplier relative to standard test timeout to use")
+    parser.add_argument("--repeat", action="store", type=int, default=1,
+                        help="Number of times to run the tests")
 
 
     #Legacy options until mozharness is updated
